Anarch Revolt Torrance, California January 26th 2002 Mike Nilsen https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/9K3-NzdNdIg/discussion This is the exact deck I used during the tourny, there were some changes from the normal version as I'm experimenting with it some. The beauty of this deck is you can bleed anyone(gaining pool) and reverse alot, thus even with little or no votes(5 max) or combat you can still have a say in whats going on. In this Tournament, the second qualifing round and the final round I back bled almost the whole time. Crypt (12 cards, min=19, max=31, avg=6.33) ------------------------------------------ 2x Korah 7 AUS DEM OBF ani priscus Malkavian antitribu:2 2x Artemis 6 DEM OBF aus cel for Malkavian antitribu:2 2x Dolphin Black 6 AUS DEM OBF Malkavian antitribu:2 1x Anatole, Prophet of Gehenna 8 AUS DEM OBF dom for Malkavian:2 1x Theron 8 AUS DEM OBF for obt Malkavian antitribu:2 1x Virgil 8 AUS DEM OBF cel bishop Malkavian antitribu:2 1x Kite 7 AUS DEM obf pre bishop Malkavian antitribu:2 1x Claven 4 aus dem obf Malkavian antitribu:2 1x Yorik 3 dem obf Malkavian antitribu:2 Library (90 cards) Master (19) 1x Antediluvian Awakening 4x Blood Doll 2x Information Highway 2x Minion Tap 2x Parthenon, The 8x Sudden Reversal Action (18) 18x Kindred Spirits Action Modifier (45) 6x Cloak the Gathering 6x Confusion 4x Elder Impersonation 10x Eyes of Chaos 6x Faceless Night 6x Lost in Crowds 7x Spying Mission Action Modifier/Combat (8) 8x Swallowed by the Night